'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_VERSION_GLES1_1_0'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_VERSION_GLES1_1_0',error_checker=_errors._error_checker)
GL_ACTIVE_TEXTURE=_C('GL_ACTIVE_TEXTURE',0x84E0)
GL_ADD=_C('GL_ADD',0x0104)
GL_ADD_SIGNED=_C('GL_ADD_SIGNED',0x8574)
GL_ALIASED_LINE_WIDTH_RANGE=_C('GL_ALIASED_LINE_WIDTH_RANGE',0x846E)
GL_ALIASED_POINT_SIZE_RANGE=_C('GL_ALIASED_POINT_SIZE_RANGE',0x846D)
GL_ALPHA=_C('GL_ALPHA',0x1906)
GL_ALPHA_BITS=_C('GL_ALPHA_BITS',0x0D55)
GL_ALPHA_SCALE=_C('GL_ALPHA_SCALE',0x0D1C)
GL_ALPHA_TEST=_C('GL_ALPHA_TEST',0x0BC0)
GL_ALPHA_TEST_FUNC=_C('GL_ALPHA_TEST_FUNC',0x0BC1)
GL_ALPHA_TEST_REF=_C('GL_ALPHA_TEST_REF',0x0BC2)
GL_ALWAYS=_C('GL_ALWAYS',0x0207)
GL_AMBIENT=_C('GL_AMBIENT',0x1200)
GL_AMBIENT_AND_DIFFUSE=_C('GL_AMBIENT_AND_DIFFUSE',0x1602)
GL_AND=_C('GL_AND',0x1501)
GL_AND_INVERTED=_C('GL_AND_INVERTED',0x1504)
GL_AND_REVERSE=_C('GL_AND_REVERSE',0x1502)
GL_ARRAY_BUFFER=_C('GL_ARRAY_BUFFER',0x8892)
GL_ARRAY_BUFFER_BINDING=_C('GL_ARRAY_BUFFER_BINDING',0x8894)
GL_BACK=_C('GL_BACK',0x0405)
GL_BLEND=_C('GL_BLEND',0x0BE2)
GL_BLEND_DST=_C('GL_BLEND_DST',0x0BE0)
GL_BLEND_SRC=_C('GL_BLEND_SRC',0x0BE1)
GL_BLUE_BITS=_C('GL_BLUE_BITS',0x0D54)
GL_BUFFER_SIZE=_C('GL_BUFFER_SIZE',0x8764)
GL_BUFFER_USAGE=_C('GL_BUFFER_USAGE',0x8765)
GL_BYTE=_C('GL_BYTE',0x1400)
GL_CCW=_C('GL_CCW',0x0901)
GL_CLAMP_TO_EDGE=_C('GL_CLAMP_TO_EDGE',0x812F)
GL_CLEAR=_C('GL_CLEAR',0x1500)
GL_CLIENT_ACTIVE_TEXTURE=_C('GL_CLIENT_ACTIVE_TEXTURE',0x84E1)
GL_CLIP_PLANE0=_C('GL_CLIP_PLANE0',0x3000)
GL_CLIP_PLANE1=_C('GL_CLIP_PLANE1',0x3001)
GL_CLIP_PLANE2=_C('GL_CLIP_PLANE2',0x3002)
GL_CLIP_PLANE3=_C('GL_CLIP_PLANE3',0x3003)
GL_CLIP_PLANE4=_C('GL_CLIP_PLANE4',0x3004)
GL_CLIP_PLANE5=_C('GL_CLIP_PLANE5',0x3005)
GL_COLOR_ARRAY=_C('GL_COLOR_ARRAY',0x8076)
GL_COLOR_ARRAY_BUFFER_BINDING=_C('GL_COLOR_ARRAY_BUFFER_BINDING',0x8898)
GL_COLOR_ARRAY_POINTER=_C('GL_COLOR_ARRAY_POINTER',0x8090)
GL_COLOR_ARRAY_SIZE=_C('GL_COLOR_ARRAY_SIZE',0x8081)
GL_COLOR_ARRAY_STRIDE=_C('GL_COLOR_ARRAY_STRIDE',0x8083)
GL_COLOR_ARRAY_TYPE=_C('GL_COLOR_ARRAY_TYPE',0x8082)
GL_COLOR_BUFFER_BIT=_C('GL_COLOR_BUFFER_BIT',0x00004000)
GL_COLOR_CLEAR_VALUE=_C('GL_COLOR_CLEAR_VALUE',0x0C22)
GL_COLOR_LOGIC_OP=_C('GL_COLOR_LOGIC_OP',0x0BF2)
GL_COLOR_MATERIAL=_C('GL_COLOR_MATERIAL',0x0B57)
GL_COLOR_WRITEMASK=_C('GL_COLOR_WRITEMASK',0x0C23)
GL_COMBINE=_C('GL_COMBINE',0x8570)
GL_COMBINE_ALPHA=_C('GL_COMBINE_ALPHA',0x8572)
GL_COMBINE_RGB=_C('GL_COMBINE_RGB',0x8571)
GL_COMPRESSED_TEXTURE_FORMATS=_C('GL_COMPRESSED_TEXTURE_FORMATS',0x86A3)
GL_CONSTANT=_C('GL_CONSTANT',0x8576)
GL_CONSTANT_ATTENUATION=_C('GL_CONSTANT_ATTENUATION',0x1207)
GL_COPY=_C('GL_COPY',0x1503)
GL_COPY_INVERTED=_C('GL_COPY_INVERTED',0x150C)
GL_CULL_FACE=_C('GL_CULL_FACE',0x0B44)
GL_CULL_FACE_MODE=_C('GL_CULL_FACE_MODE',0x0B45)
GL_CURRENT_COLOR=_C('GL_CURRENT_COLOR',0x0B00)
GL_CURRENT_NORMAL=_C('GL_CURRENT_NORMAL',0x0B02)
GL_CURRENT_TEXTURE_COORDS=_C('GL_CURRENT_TEXTURE_COORDS',0x0B03)
GL_CW=_C('GL_CW',0x0900)
GL_DECAL=_C('GL_DECAL',0x2101)
GL_DECR=_C('GL_DECR',0x1E03)
GL_DEPTH_BITS=_C('GL_DEPTH_BITS',0x0D56)
GL_DEPTH_BUFFER_BIT=_C('GL_DEPTH_BUFFER_BIT',0x00000100)
GL_DEPTH_CLEAR_VALUE=_C('GL_DEPTH_CLEAR_VALUE',0x0B73)
GL_DEPTH_FUNC=_C('GL_DEPTH_FUNC',0x0B74)
GL_DEPTH_RANGE=_C('GL_DEPTH_RANGE',0x0B70)
GL_DEPTH_TEST=_C('GL_DEPTH_TEST',0x0B71)
GL_DEPTH_WRITEMASK=_C('GL_DEPTH_WRITEMASK',0x0B72)
GL_DIFFUSE=_C('GL_DIFFUSE',0x1201)
GL_DITHER=_C('GL_DITHER',0x0BD0)
GL_DONT_CARE=_C('GL_DONT_CARE',0x1100)
GL_DOT3_RGB=_C('GL_DOT3_RGB',0x86AE)
GL_DOT3_RGBA=_C('GL_DOT3_RGBA',0x86AF)
GL_DST_ALPHA=_C('GL_DST_ALPHA',0x0304)
GL_DST_COLOR=_C('GL_DST_COLOR',0x0306)
GL_DYNAMIC_DRAW=_C('GL_DYNAMIC_DRAW',0x88E8)
GL_ELEMENT_ARRAY_BUFFER=_C('GL_ELEMENT_ARRAY_BUFFER',0x8893)
GL_ELEMENT_ARRAY_BUFFER_BINDING=_C('GL_ELEMENT_ARRAY_BUFFER_BINDING',0x8895)
GL_EMISSION=_C('GL_EMISSION',0x1600)
GL_EQUAL=_C('GL_EQUAL',0x0202)
GL_EQUIV=_C('GL_EQUIV',0x1509)
GL_EXP=_C('GL_EXP',0x0800)
GL_EXP2=_C('GL_EXP2',0x0801)
GL_EXTENSIONS=_C('GL_EXTENSIONS',0x1F03)
GL_FALSE=_C('GL_FALSE',0)
GL_FASTEST=_C('GL_FASTEST',0x1101)
GL_FIXED=_C('GL_FIXED',0x140C)
GL_FLAT=_C('GL_FLAT',0x1D00)
GL_FLOAT=_C('GL_FLOAT',0x1406)
GL_FOG=_C('GL_FOG',0x0B60)
GL_FOG_COLOR=_C('GL_FOG_COLOR',0x0B66)
GL_FOG_DENSITY=_C('GL_FOG_DENSITY',0x0B62)
GL_FOG_END=_C('GL_FOG_END',0x0B64)
GL_FOG_HINT=_C('GL_FOG_HINT',0x0C54)
GL_FOG_MODE=_C('GL_FOG_MODE',0x0B65)
GL_FOG_START=_C('GL_FOG_START',0x0B63)
GL_FRONT=_C('GL_FRONT',0x0404)
GL_FRONT_AND_BACK=_C('GL_FRONT_AND_BACK',0x0408)
GL_FRONT_FACE=_C('GL_FRONT_FACE',0x0B46)
GL_GENERATE_MIPMAP=_C('GL_GENERATE_MIPMAP',0x8191)
GL_GENERATE_MIPMAP_HINT=_C('GL_GENERATE_MIPMAP_HINT',0x8192)
GL_GEQUAL=_C('GL_GEQUAL',0x0206)
GL_GREATER=_C('GL_GREATER',0x0204)
GL_GREEN_BITS=_C('GL_GREEN_BITS',0x0D53)
GL_INCR=_C('GL_INCR',0x1E02)
GL_INTERPOLATE=_C('GL_INTERPOLATE',0x8575)
GL_INVALID_ENUM=_C('GL_INVALID_ENUM',0x0500)
GL_INVALID_OPERATION=_C('GL_INVALID_OPERATION',0x0502)
GL_INVALID_VALUE=_C('GL_INVALID_VALUE',0x0501)
GL_INVERT=_C('GL_INVERT',0x150A)
GL_KEEP=_C('GL_KEEP',0x1E00)
GL_LEQUAL=_C('GL_LEQUAL',0x0203)
GL_LESS=_C('GL_LESS',0x0201)
GL_LIGHT0=_C('GL_LIGHT0',0x4000)
GL_LIGHT1=_C('GL_LIGHT1',0x4001)
GL_LIGHT2=_C('GL_LIGHT2',0x4002)
GL_LIGHT3=_C('GL_LIGHT3',0x4003)
GL_LIGHT4=_C('GL_LIGHT4',0x4004)
GL_LIGHT5=_C('GL_LIGHT5',0x4005)
GL_LIGHT6=_C('GL_LIGHT6',0x4006)
GL_LIGHT7=_C('GL_LIGHT7',0x4007)
GL_LIGHTING=_C('GL_LIGHTING',0x0B50)
GL_LIGHT_MODEL_AMBIENT=_C('GL_LIGHT_MODEL_AMBIENT',0x0B53)
GL_LIGHT_MODEL_TWO_SIDE=_C('GL_LIGHT_MODEL_TWO_SIDE',0x0B52)
GL_LINEAR=_C('GL_LINEAR',0x2601)
GL_LINEAR_ATTENUATION=_C('GL_LINEAR_ATTENUATION',0x1208)
GL_LINEAR_MIPMAP_LINEAR=_C('GL_LINEAR_MIPMAP_LINEAR',0x2703)
GL_LINEAR_MIPMAP_NEAREST=_C('GL_LINEAR_MIPMAP_NEAREST',0x2701)
GL_LINES=_C('GL_LINES',0x0001)
GL_LINE_LOOP=_C('GL_LINE_LOOP',0x0002)
GL_LINE_SMOOTH=_C('GL_LINE_SMOOTH',0x0B20)
GL_LINE_SMOOTH_HINT=_C('GL_LINE_SMOOTH_HINT',0x0C52)
GL_LINE_STRIP=_C('GL_LINE_STRIP',0x0003)
GL_LINE_WIDTH=_C('GL_LINE_WIDTH',0x0B21)
GL_LOGIC_OP_MODE=_C('GL_LOGIC_OP_MODE',0x0BF0)
GL_LUMINANCE=_C('GL_LUMINANCE',0x1909)
GL_LUMINANCE_ALPHA=_C('GL_LUMINANCE_ALPHA',0x190A)
GL_MATRIX_MODE=_C('GL_MATRIX_MODE',0x0BA0)
GL_MAX_CLIP_PLANES=_C('GL_MAX_CLIP_PLANES',0x0D32)
GL_MAX_LIGHTS=_C('GL_MAX_LIGHTS',0x0D31)
GL_MAX_MODELVIEW_STACK_DEPTH=_C('GL_MAX_MODELVIEW_STACK_DEPTH',0x0D36)
GL_MAX_PROJECTION_STACK_DEPTH=_C('GL_MAX_PROJECTION_STACK_DEPTH',0x0D38)
GL_MAX_TEXTURE_SIZE=_C('GL_MAX_TEXTURE_SIZE',0x0D33)
GL_MAX_TEXTURE_STACK_DEPTH=_C('GL_MAX_TEXTURE_STACK_DEPTH',0x0D39)
GL_MAX_TEXTURE_UNITS=_C('GL_MAX_TEXTURE_UNITS',0x84E2)
GL_MAX_VIEWPORT_DIMS=_C('GL_MAX_VIEWPORT_DIMS',0x0D3A)
GL_MODELVIEW=_C('GL_MODELVIEW',0x1700)
GL_MODELVIEW_MATRIX=_C('GL_MODELVIEW_MATRIX',0x0BA6)
GL_MODELVIEW_STACK_DEPTH=_C('GL_MODELVIEW_STACK_DEPTH',0x0BA3)
GL_MODULATE=_C('GL_MODULATE',0x2100)
GL_MULTISAMPLE=_C('GL_MULTISAMPLE',0x809D)
GL_NAND=_C('GL_NAND',0x150E)
GL_NEAREST=_C('GL_NEAREST',0x2600)
GL_NEAREST_MIPMAP_LINEAR=_C('GL_NEAREST_MIPMAP_LINEAR',0x2702)
GL_NEAREST_MIPMAP_NEAREST=_C('GL_NEAREST_MIPMAP_NEAREST',0x2700)
GL_NEVER=_C('GL_NEVER',0x0200)
GL_NICEST=_C('GL_NICEST',0x1102)
GL_NOOP=_C('GL_NOOP',0x1505)
GL_NOR=_C('GL_NOR',0x1508)
GL_NORMALIZE=_C('GL_NORMALIZE',0x0BA1)
GL_NORMAL_ARRAY=_C('GL_NORMAL_ARRAY',0x8075)
GL_NORMAL_ARRAY_BUFFER_BINDING=_C('GL_NORMAL_ARRAY_BUFFER_BINDING',0x8897)
GL_NORMAL_ARRAY_POINTER=_C('GL_NORMAL_ARRAY_POINTER',0x808F)
GL_NORMAL_ARRAY_STRIDE=_C('GL_NORMAL_ARRAY_STRIDE',0x807F)
GL_NORMAL_ARRAY_TYPE=_C('GL_NORMAL_ARRAY_TYPE',0x807E)
GL_NOTEQUAL=_C('GL_NOTEQUAL',0x0205)
GL_NO_ERROR=_C('GL_NO_ERROR',0)
GL_NUM_COMPRESSED_TEXTURE_FORMATS=_C('GL_NUM_COMPRESSED_TEXTURE_FORMATS',0x86A2)
GL_ONE=_C('GL_ONE',1)
GL_ONE_MINUS_DST_ALPHA=_C('GL_ONE_MINUS_DST_ALPHA',0x0305)
GL_ONE_MINUS_DST_COLOR=_C('GL_ONE_MINUS_DST_COLOR',0x0307)
GL_ONE_MINUS_SRC_ALPHA=_C('GL_ONE_MINUS_SRC_ALPHA',0x0303)
GL_ONE_MINUS_SRC_COLOR=_C('GL_ONE_MINUS_SRC_COLOR',0x0301)
GL_OPERAND0_ALPHA=_C('GL_OPERAND0_ALPHA',0x8598)
GL_OPERAND0_RGB=_C('GL_OPERAND0_RGB',0x8590)
GL_OPERAND1_ALPHA=_C('GL_OPERAND1_ALPHA',0x8599)
GL_OPERAND1_RGB=_C('GL_OPERAND1_RGB',0x8591)
GL_OPERAND2_ALPHA=_C('GL_OPERAND2_ALPHA',0x859A)
GL_OPERAND2_RGB=_C('GL_OPERAND2_RGB',0x8592)
GL_OR=_C('GL_OR',0x1507)
GL_OR_INVERTED=_C('GL_OR_INVERTED',0x150D)
GL_OR_REVERSE=_C('GL_OR_REVERSE',0x150B)
GL_OUT_OF_MEMORY=_C('GL_OUT_OF_MEMORY',0x0505)
GL_PACK_ALIGNMENT=_C('GL_PACK_ALIGNMENT',0x0D05)
GL_PERSPECTIVE_CORRECTION_HINT=_C('GL_PERSPECTIVE_CORRECTION_HINT',0x0C50)
GL_POINTS=_C('GL_POINTS',0x0000)
GL_POINT_DISTANCE_ATTENUATION=_C('GL_POINT_DISTANCE_ATTENUATION',0x8129)
GL_POINT_FADE_THRESHOLD_SIZE=_C('GL_POINT_FADE_THRESHOLD_SIZE',0x8128)
GL_POINT_SIZE=_C('GL_POINT_SIZE',0x0B11)
GL_POINT_SIZE_MAX=_C('GL_POINT_SIZE_MAX',0x8127)
GL_POINT_SIZE_MIN=_C('GL_POINT_SIZE_MIN',0x8126)
GL_POINT_SMOOTH=_C('GL_POINT_SMOOTH',0x0B10)
GL_POINT_SMOOTH_HINT=_C('GL_POINT_SMOOTH_HINT',0x0C51)
GL_POLYGON_OFFSET_FACTOR=_C('GL_POLYGON_OFFSET_FACTOR',0x8038)
GL_POLYGON_OFFSET_FILL=_C('GL_POLYGON_OFFSET_FILL',0x8037)
GL_POLYGON_OFFSET_UNITS=_C('GL_POLYGON_OFFSET_UNITS',0x2A00)
GL_POSITION=_C('GL_POSITION',0x1203)
GL_PREVIOUS=_C('GL_PREVIOUS',0x8578)
GL_PRIMARY_COLOR=_C('GL_PRIMARY_COLOR',0x8577)
GL_PROJECTION=_C('GL_PROJECTION',0x1701)
GL_PROJECTION_MATRIX=_C('GL_PROJECTION_MATRIX',0x0BA7)
GL_PROJECTION_STACK_DEPTH=_C('GL_PROJECTION_STACK_DEPTH',0x0BA4)
GL_QUADRATIC_ATTENUATION=_C('GL_QUADRATIC_ATTENUATION',0x1209)
GL_RED_BITS=_C('GL_RED_BITS',0x0D52)
GL_RENDERER=_C('GL_RENDERER',0x1F01)
GL_REPEAT=_C('GL_REPEAT',0x2901)
GL_REPLACE=_C('GL_REPLACE',0x1E01)
GL_RESCALE_NORMAL=_C('GL_RESCALE_NORMAL',0x803A)
GL_RGB=_C('GL_RGB',0x1907)
GL_RGBA=_C('GL_RGBA',0x1908)
GL_RGB_SCALE=_C('GL_RGB_SCALE',0x8573)
GL_SAMPLES=_C('GL_SAMPLES',0x80A9)
GL_SAMPLE_ALPHA_TO_COVERAGE=_C('GL_SAMPLE_ALPHA_TO_COVERAGE',0x809E)
GL_SAMPLE_ALPHA_TO_ONE=_C('GL_SAMPLE_ALPHA_TO_ONE',0x809F)
GL_SAMPLE_BUFFERS=_C('GL_SAMPLE_BUFFERS',0x80A8)
GL_SAMPLE_COVERAGE=_C('GL_SAMPLE_COVERAGE',0x80A0)
GL_SAMPLE_COVERAGE_INVERT=_C('GL_SAMPLE_COVERAGE_INVERT',0x80AB)
GL_SAMPLE_COVERAGE_VALUE=_C('GL_SAMPLE_COVERAGE_VALUE',0x80AA)
GL_SCISSOR_BOX=_C('GL_SCISSOR_BOX',0x0C10)
GL_SCISSOR_TEST=_C('GL_SCISSOR_TEST',0x0C11)
GL_SET=_C('GL_SET',0x150F)
GL_SHADE_MODEL=_C('GL_SHADE_MODEL',0x0B54)
GL_SHININESS=_C('GL_SHININESS',0x1601)
GL_SHORT=_C('GL_SHORT',0x1402)
GL_SMOOTH=_C('GL_SMOOTH',0x1D01)
GL_SMOOTH_LINE_WIDTH_RANGE=_C('GL_SMOOTH_LINE_WIDTH_RANGE',0x0B22)
GL_SMOOTH_POINT_SIZE_RANGE=_C('GL_SMOOTH_POINT_SIZE_RANGE',0x0B12)
GL_SPECULAR=_C('GL_SPECULAR',0x1202)
GL_SPOT_CUTOFF=_C('GL_SPOT_CUTOFF',0x1206)
GL_SPOT_DIRECTION=_C('GL_SPOT_DIRECTION',0x1204)
GL_SPOT_EXPONENT=_C('GL_SPOT_EXPONENT',0x1205)
GL_SRC0_ALPHA=_C('GL_SRC0_ALPHA',0x8588)
GL_SRC0_RGB=_C('GL_SRC0_RGB',0x8580)
GL_SRC1_ALPHA=_C('GL_SRC1_ALPHA',0x8589)
GL_SRC1_RGB=_C('GL_SRC1_RGB',0x8581)
GL_SRC2_ALPHA=_C('GL_SRC2_ALPHA',0x858A)
GL_SRC2_RGB=_C('GL_SRC2_RGB',0x8582)
GL_SRC_ALPHA=_C('GL_SRC_ALPHA',0x0302)
GL_SRC_ALPHA_SATURATE=_C('GL_SRC_ALPHA_SATURATE',0x0308)
GL_SRC_COLOR=_C('GL_SRC_COLOR',0x0300)
GL_STACK_OVERFLOW=_C('GL_STACK_OVERFLOW',0x0503)
GL_STACK_UNDERFLOW=_C('GL_STACK_UNDERFLOW',0x0504)
GL_STATIC_DRAW=_C('GL_STATIC_DRAW',0x88E4)
GL_STENCIL_BITS=_C('GL_STENCIL_BITS',0x0D57)
GL_STENCIL_BUFFER_BIT=_C('GL_STENCIL_BUFFER_BIT',0x00000400)
GL_STENCIL_CLEAR_VALUE=_C('GL_STENCIL_CLEAR_VALUE',0x0B91)
GL_STENCIL_FAIL=_C('GL_STENCIL_FAIL',0x0B94)
GL_STENCIL_FUNC=_C('GL_STENCIL_FUNC',0x0B92)
GL_STENCIL_PASS_DEPTH_FAIL=_C('GL_STENCIL_PASS_DEPTH_FAIL',0x0B95)
GL_STENCIL_PASS_DEPTH_PASS=_C('GL_STENCIL_PASS_DEPTH_PASS',0x0B96)
GL_STENCIL_REF=_C('GL_STENCIL_REF',0x0B97)
GL_STENCIL_TEST=_C('GL_STENCIL_TEST',0x0B90)
GL_STENCIL_VALUE_MASK=_C('GL_STENCIL_VALUE_MASK',0x0B93)
GL_STENCIL_WRITEMASK=_C('GL_STENCIL_WRITEMASK',0x0B98)
GL_SUBPIXEL_BITS=_C('GL_SUBPIXEL_BITS',0x0D50)
GL_SUBTRACT=_C('GL_SUBTRACT',0x84E7)
GL_TEXTURE=_C('GL_TEXTURE',0x1702)
GL_TEXTURE0=_C('GL_TEXTURE0',0x84C0)
GL_TEXTURE1=_C('GL_TEXTURE1',0x84C1)
GL_TEXTURE10=_C('GL_TEXTURE10',0x84CA)
GL_TEXTURE11=_C('GL_TEXTURE11',0x84CB)
GL_TEXTURE12=_C('GL_TEXTURE12',0x84CC)
GL_TEXTURE13=_C('GL_TEXTURE13',0x84CD)
GL_TEXTURE14=_C('GL_TEXTURE14',0x84CE)
GL_TEXTURE15=_C('GL_TEXTURE15',0x84CF)
GL_TEXTURE16=_C('GL_TEXTURE16',0x84D0)
GL_TEXTURE17=_C('GL_TEXTURE17',0x84D1)
GL_TEXTURE18=_C('GL_TEXTURE18',0x84D2)
GL_TEXTURE19=_C('GL_TEXTURE19',0x84D3)
GL_TEXTURE2=_C('GL_TEXTURE2',0x84C2)
GL_TEXTURE20=_C('GL_TEXTURE20',0x84D4)
GL_TEXTURE21=_C('GL_TEXTURE21',0x84D5)
GL_TEXTURE22=_C('GL_TEXTURE22',0x84D6)
GL_TEXTURE23=_C('GL_TEXTURE23',0x84D7)
GL_TEXTURE24=_C('GL_TEXTURE24',0x84D8)
GL_TEXTURE25=_C('GL_TEXTURE25',0x84D9)
GL_TEXTURE26=_C('GL_TEXTURE26',0x84DA)
GL_TEXTURE27=_C('GL_TEXTURE27',0x84DB)
GL_TEXTURE28=_C('GL_TEXTURE28',0x84DC)
GL_TEXTURE29=_C('GL_TEXTURE29',0x84DD)
GL_TEXTURE3=_C('GL_TEXTURE3',0x84C3)
GL_TEXTURE30=_C('GL_TEXTURE30',0x84DE)
GL_TEXTURE31=_C('GL_TEXTURE31',0x84DF)
GL_TEXTURE4=_C('GL_TEXTURE4',0x84C4)
GL_TEXTURE5=_C('GL_TEXTURE5',0x84C5)
GL_TEXTURE6=_C('GL_TEXTURE6',0x84C6)
GL_TEXTURE7=_C('GL_TEXTURE7',0x84C7)
GL_TEXTURE8=_C('GL_TEXTURE8',0x84C8)
GL_TEXTURE9=_C('GL_TEXTURE9',0x84C9)
GL_TEXTURE_2D=_C('GL_TEXTURE_2D',0x0DE1)
GL_TEXTURE_BINDING_2D=_C('GL_TEXTURE_BINDING_2D',0x8069)
GL_TEXTURE_COORD_ARRAY=_C('GL_TEXTURE_COORD_ARRAY',0x8078)
GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING=_C('GL_TEXTURE_COORD_ARRAY_BUFFER_BINDING',0x889A)
GL_TEXTURE_COORD_ARRAY_POINTER=_C('GL_TEXTURE_COORD_ARRAY_POINTER',0x8092)
GL_TEXTURE_COORD_ARRAY_SIZE=_C('GL_TEXTURE_COORD_ARRAY_SIZE',0x8088)
GL_TEXTURE_COORD_ARRAY_STRIDE=_C('GL_TEXTURE_COORD_ARRAY_STRIDE',0x808A)
GL_TEXTURE_COORD_ARRAY_TYPE=_C('GL_TEXTURE_COORD_ARRAY_TYPE',0x8089)
GL_TEXTURE_ENV=_C('GL_TEXTURE_ENV',0x2300)
GL_TEXTURE_ENV_COLOR=_C('GL_TEXTURE_ENV_COLOR',0x2201)
GL_TEXTURE_ENV_MODE=_C('GL_TEXTURE_ENV_MODE',0x2200)
GL_TEXTURE_MAG_FILTER=_C('GL_TEXTURE_MAG_FILTER',0x2800)
GL_TEXTURE_MATRIX=_C('GL_TEXTURE_MATRIX',0x0BA8)
GL_TEXTURE_MIN_FILTER=_C('GL_TEXTURE_MIN_FILTER',0x2801)
GL_TEXTURE_STACK_DEPTH=_C('GL_TEXTURE_STACK_DEPTH',0x0BA5)
GL_TEXTURE_WRAP_S=_C('GL_TEXTURE_WRAP_S',0x2802)
GL_TEXTURE_WRAP_T=_C('GL_TEXTURE_WRAP_T',0x2803)
GL_TRIANGLES=_C('GL_TRIANGLES',0x0004)
GL_TRIANGLE_FAN=_C('GL_TRIANGLE_FAN',0x0006)
GL_TRIANGLE_STRIP=_C('GL_TRIANGLE_STRIP',0x0005)
GL_TRUE=_C('GL_TRUE',1)
GL_UNPACK_ALIGNMENT=_C('GL_UNPACK_ALIGNMENT',0x0CF5)
GL_UNSIGNED_BYTE=_C('GL_UNSIGNED_BYTE',0x1401)
GL_UNSIGNED_SHORT=_C('GL_UNSIGNED_SHORT',0x1403)
GL_UNSIGNED_SHORT_4_4_4_4=_C('GL_UNSIGNED_SHORT_4_4_4_4',0x8033)
GL_UNSIGNED_SHORT_5_5_5_1=_C('GL_UNSIGNED_SHORT_5_5_5_1',0x8034)
GL_UNSIGNED_SHORT_5_6_5=_C('GL_UNSIGNED_SHORT_5_6_5',0x8363)
GL_VENDOR=_C('GL_VENDOR',0x1F00)
GL_VERSION=_C('GL_VERSION',0x1F02)
GL_VERSION_ES_CL_1_0=_C('GL_VERSION_ES_CL_1_0',1)
GL_VERSION_ES_CL_1_1=_C('GL_VERSION_ES_CL_1_1',1)
GL_VERSION_ES_CM_1_1=_C('GL_VERSION_ES_CM_1_1',1)
GL_VERTEX_ARRAY=_C('GL_VERTEX_ARRAY',0x8074)
GL_VERTEX_ARRAY_BUFFER_BINDING=_C('GL_VERTEX_ARRAY_BUFFER_BINDING',0x8896)
GL_VERTEX_ARRAY_POINTER=_C('GL_VERTEX_ARRAY_POINTER',0x808E)
GL_VERTEX_ARRAY_SIZE=_C('GL_VERTEX_ARRAY_SIZE',0x807A)
GL_VERTEX_ARRAY_STRIDE=_C('GL_VERTEX_ARRAY_STRIDE',0x807C)
GL_VERTEX_ARRAY_TYPE=_C('GL_VERTEX_ARRAY_TYPE',0x807B)
GL_VIEWPORT=_C('GL_VIEWPORT',0x0BA2)
GL_XOR=_C('GL_XOR',0x1506)
GL_ZERO=_C('GL_ZERO',0)
@_f
@_p.types(None,_cs.GLenum)
def glActiveTexture(texture):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glAlphaFunc(func,ref):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glAlphaFuncx(func,ref):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindBuffer(target,buffer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint)
def glBindTexture(target,texture):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glBlendFunc(sfactor,dfactor):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizeiptr,ctypes.c_void_p,_cs.GLenum)
def glBufferData(target,size,data,usage):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLintptr,_cs.GLsizeiptr,ctypes.c_void_p)
def glBufferSubData(target,offset,size,data):pass
@_f
@_p.types(None,_cs.GLbitfield)
def glClear(mask):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glClearColor(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glClearColorx(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLfloat)
def glClearDepthf(d):pass
@_f
@_p.types(None,_cs.GLfixed)
def glClearDepthx(depth):pass
@_f
@_p.types(None,_cs.GLint)
def glClearStencil(s):pass
@_f
@_p.types(None,_cs.GLenum)
def glClientActiveTexture(texture):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glClipPlanef(p,eqn):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glClipPlanex(plane,equation):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glColor4f(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glColor4ub(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glColor4x(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean,_cs.GLboolean)
def glColorMask(red,green,blue,alpha):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glColorPointer(size,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLsizei,ctypes.c_void_p)
def glCompressedTexImage2D(target,level,internalformat,width,height,border,imageSize,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glCompressedTexSubImage2D(target,level,xoffset,yoffset,width,height,format,imageSize,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLint)
def glCopyTexImage2D(target,level,internalformat,x,y,width,height,border):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glCopyTexSubImage2D(target,level,xoffset,yoffset,x,y,width,height):pass
@_f
@_p.types(None,_cs.GLenum)
def glCullFace(mode):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteBuffers(n,buffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glDeleteTextures(n,textures):pass
@_f
@_p.types(None,_cs.GLenum)
def glDepthFunc(func):pass
@_f
@_p.types(None,_cs.GLboolean)
def glDepthMask(flag):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glDepthRangef(n,f):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glDepthRangex(n,f):pass
@_f
@_p.types(None,_cs.GLenum)
def glDisable(cap):pass
@_f
@_p.types(None,_cs.GLenum)
def glDisableClientState(array):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLsizei)
def glDrawArrays(mode,first,count):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,_cs.GLenum,ctypes.c_void_p)
def glDrawElements(mode,count,type,indices):pass
@_f
@_p.types(None,_cs.GLenum)
def glEnable(cap):pass
@_f
@_p.types(None,_cs.GLenum)
def glEnableClientState(array):pass
@_f
@_p.types(None,)
def glFinish():pass
@_f
@_p.types(None,)
def glFlush():pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glFogf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glFogfv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glFogx(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glFogxv(pname,param):pass
@_f
@_p.types(None,_cs.GLenum)
def glFrontFace(mode):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glFrustumf(l,r,b,t,n,f):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glFrustumx(l,r,b,t,n,f):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenBuffers(n,buffers):pass
@_f
@_p.types(None,_cs.GLsizei,arrays.GLuintArray)
def glGenTextures(n,textures):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLbooleanArray)
def glGetBooleanv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetBufferParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glGetClipPlanef(plane,equation):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glGetClipPlanex(plane,equation):pass
@_f
@_p.types(_cs.GLenum,)
def glGetError():pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glGetFixedv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glGetFloatv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glGetIntegerv(pname,data):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetLightfv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetLightxv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetMaterialfv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetMaterialxv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLvoidpArray)
def glGetPointerv(pname,params):pass
@_f
@_p.types(arrays.GLubyteArray,_cs.GLenum)
def glGetString(name):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetTexEnvfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexEnviv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetTexEnvxv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glGetTexParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glGetTexParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glGetTexParameterxv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum)
def glHint(target,mode):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsBuffer(buffer):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLenum)
def glIsEnabled(cap):pass
@_f
@_p.types(_cs.GLboolean,_cs.GLuint)
def glIsTexture(texture):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glLightModelf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glLightModelfv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glLightModelx(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glLightModelxv(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glLightf(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glLightfv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glLightx(light,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glLightxv(light,pname,params):pass
@_f
@_p.types(None,_cs.GLfloat)
def glLineWidth(width):pass
@_f
@_p.types(None,_cs.GLfixed)
def glLineWidthx(width):pass
@_f
@_p.types(None,)
def glLoadIdentity():pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glLoadMatrixf(m):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glLoadMatrixx(m):pass
@_f
@_p.types(None,_cs.GLenum)
def glLogicOp(opcode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glMaterialf(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glMaterialfv(face,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glMaterialx(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glMaterialxv(face,pname,param):pass
@_f
@_p.types(None,_cs.GLenum)
def glMatrixMode(mode):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glMultMatrixf(m):pass
@_f
@_p.types(None,arrays.GLfixedArray)
def glMultMatrixx(m):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glMultiTexCoord4f(target,s,t,r,q):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glMultiTexCoord4x(texture,s,t,r,q):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glNormal3f(nx,ny,nz):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glNormal3x(nx,ny,nz):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glNormalPointer(type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glOrthof(l,r,b,t,n,f):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glOrthox(l,r,b,t,n,f):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glPixelStorei(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glPointParameterf(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glPointParameterfv(pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfixed)
def glPointParameterx(pname,param):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfixedArray)
def glPointParameterxv(pname,params):pass
@_f
@_p.types(None,_cs.GLfloat)
def glPointSize(size):pass
@_f
@_p.types(None,_cs.GLfixed)
def glPointSizex(size):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat)
def glPolygonOffset(factor,units):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed)
def glPolygonOffsetx(factor,units):pass
@_f
@_p.types(None,)
def glPopMatrix():pass
@_f
@_p.types(None,)
def glPushMatrix():pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glReadPixels(x,y,width,height,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glRotatef(angle,x,y,z):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glRotatex(angle,x,y,z):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLboolean)
def glSampleCoverage(value,invert):pass
@_f
@_p.types(None,_cs.GLclampx,_cs.GLboolean)
def glSampleCoveragex(value,invert):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glScalef(x,y,z):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glScalex(x,y,z):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glScissor(x,y,width,height):pass
@_f
@_p.types(None,_cs.GLenum)
def glShadeModel(mode):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLuint)
def glStencilFunc(func,ref,mask):pass
@_f
@_p.types(None,_cs.GLuint)
def glStencilMask(mask):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLenum)
def glStencilOp(fail,zfail,zpass):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glTexCoordPointer(size,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glTexEnvf(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glTexEnvfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glTexEnvi(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexEnviv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glTexEnvx(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glTexEnvxv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLint,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexImage2D(target,level,internalformat,width,height,border,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfloat)
def glTexParameterf(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfloatArray)
def glTexParameterfv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLint)
def glTexParameteri(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLintArray)
def glTexParameteriv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,_cs.GLfixed)
def glTexParameterx(target,pname,param):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLenum,arrays.GLfixedArray)
def glTexParameterxv(target,pname,params):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei,_cs.GLenum,_cs.GLenum,ctypes.c_void_p)
def glTexSubImage2D(target,level,xoffset,yoffset,width,height,format,type,pixels):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glTranslatef(x,y,z):pass
@_f
@_p.types(None,_cs.GLfixed,_cs.GLfixed,_cs.GLfixed)
def glTranslatex(x,y,z):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glVertexPointer(size,type,stride,pointer):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLsizei,_cs.GLsizei)
def glViewport(x,y,width,height):pass



'''OpenGL extension EXT.occlusion_query_boolean

This module customises the behaviour of the 
OpenGL.raw.GLES2.EXT.occlusion_query_boolean to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/occlusion_query_boolean.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.EXT.occlusion_query_boolean import *
from OpenGL.raw.GLES2.EXT.occlusion_query_boolean import _EXTENSION_NAME

def glInitOcclusionQueryBooleanEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glGenQueriesEXT.ids size not checked against n
glGenQueriesEXT=wrapper.wrapper(glGenQueriesEXT).setInputArraySize(
    'ids', None
)
# INPUT glDeleteQueriesEXT.ids size not checked against n
glDeleteQueriesEXT=wrapper.wrapper(glDeleteQueriesEXT).setInputArraySize(
    'ids', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension NV.vertex_program1_1

This module customises the behaviour of the 
OpenGL.raw.GL.NV.vertex_program1_1 to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension adds four new vertex program instructions (DPH,
	RCC, SUB, and ABS).
	
	This extension also supports a position-invariant vertex program
	option.  A vertex program is position-invariant when it generates
	the _exact_ same homogenuous position and window space position
	for a vertex as conventional OpenGL transformation (ignoring vertex
	blending and weighting).
	
	By default, vertex programs are _not_ guaranteed to be
	position-invariant because there is no guarantee made that the way
	a vertex program might compute its homogenous position is exactly
	identical to the way conventional OpenGL transformation computes
	its homogenous positions.  In a position-invariant vertex program,
	the homogeneous position (HPOS) is not output by the program.
	Instead, the OpenGL implementation is expected to compute the HPOS
	for position-invariant vertex programs in a manner exactly identical
	to how the homogenous position and window position are computed
	for a vertex by conventional OpenGL transformation.  In this way
	position-invariant vertex programs guarantee correct multi-pass
	rendering semantics in cases where multiple passes are rendered and
	the second and subsequent passes use a GL_EQUAL depth test.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/vertex_program1_1.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.NV.vertex_program1_1 import *
from OpenGL.raw.GL.NV.vertex_program1_1 import _EXTENSION_NAME

def glInitVertexProgram11NV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension OES.draw_elements_base_vertex

This module customises the behaviour of the 
OpenGL.raw.GLES2.OES.draw_elements_base_vertex to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/OES/draw_elements_base_vertex.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.OES.draw_elements_base_vertex import *
from OpenGL.raw.GLES2.OES.draw_elements_base_vertex import _EXTENSION_NAME

def glInitDrawElementsBaseVertexOES():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glDrawElementsBaseVertexOES.indices size not checked against 'count,type'
glDrawElementsBaseVertexOES=wrapper.wrapper(glDrawElementsBaseVertexOES).setInputArraySize(
    'indices', None
)
# INPUT glDrawRangeElementsBaseVertexOES.indices size not checked against 'count,type'
glDrawRangeElementsBaseVertexOES=wrapper.wrapper(glDrawRangeElementsBaseVertexOES).setInputArraySize(
    'indices', None
)
# INPUT glDrawElementsInstancedBaseVertexOES.indices size not checked against 'count,type'
glDrawElementsInstancedBaseVertexOES=wrapper.wrapper(glDrawElementsInstancedBaseVertexOES).setInputArraySize(
    'indices', None
)
# INPUT glMultiDrawElementsBaseVertexOES.basevertex size not checked against 'drawcount'
# INPUT glMultiDrawElementsBaseVertexOES.count size not checked against 'drawcount'
# INPUT glMultiDrawElementsBaseVertexOES.indices size not checked against 'drawcount'
glMultiDrawElementsBaseVertexOES=wrapper.wrapper(glMultiDrawElementsBaseVertexOES).setInputArraySize(
    'basevertex', None
).setInputArraySize(
    'count', None
).setInputArraySize(
    'indices', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_APPLE_element_array'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_APPLE_element_array',error_checker=_errors._error_checker)
GL_ELEMENT_ARRAY_APPLE=_C('GL_ELEMENT_ARRAY_APPLE',0x8A0C)
GL_ELEMENT_ARRAY_POINTER_APPLE=_C('GL_ELEMENT_ARRAY_POINTER_APPLE',0x8A0E)
GL_ELEMENT_ARRAY_TYPE_APPLE=_C('GL_ELEMENT_ARRAY_TYPE_APPLE',0x8A0D)
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLsizei)
def glDrawElementArrayAPPLE(mode,first,count):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,_cs.GLint,_cs.GLsizei)
def glDrawRangeElementArrayAPPLE(mode,start,end,first,count):pass
@_f
@_p.types(None,_cs.GLenum,ctypes.c_void_p)
def glElementPointerAPPLE(type,pointer):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray,arrays.GLsizeiArray,_cs.GLsizei)
def glMultiDrawElementArrayAPPLE(mode,first,count,primcount):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLuint,_cs.GLuint,arrays.GLintArray,arrays.GLsizeiArray,_cs.GLsizei)
def glMultiDrawRangeElementArrayAPPLE(mode,start,end,first,count,primcount):pass



'''OpenGL extension ARB.shading_language_420pack

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shading_language_420pack to provide a more 
Python-friendly API

Overview (from the spec)
	
	This is a language feature only extension formed from changes made
	to version 4.20 of GLSL.  It includes:
	
	* Add line-continuation using '\', as in C++.
	
	* Change from ASCII to UTF-8 for the language character set and also 
	  allow any characters inside comments.
	
	* Allow implicit conversions of return values to the declared type of 
	  the function.
	
	* The *const* keyword can be used to declare variables within a function 
	  body with initializer expressions that are not constant expressions.
	
	* Qualifiers on variable declarations no longer have to follow a strict 
	  order. The layout qualifier can be used multiple times, and multiple 
	  parameter qualifiers can be used.  However, this is not as
	  straightforward as saying declarations have arbitrary lists of 
	  initializers.  Typically, one qualifier from each class of qualifiers
	  is allowed, so care is now taken to classify them and say so.  Then, 
	  of these, order restrictions are removed.
	
	* Add layout qualifier identifier "binding" to bind the location of a
	  uniform block.  This requires version 1.4 of GLSL.  If this extension
	  is used with an earlier version than 1.4, this feature is not present.
	
	* Add layout qualifier identifier "binding" to bind units to sampler 
	  and image variable declarations.
	
	* Add C-style curly brace initializer lists syntax for initializers. 
	  Full initialization of aggregates is required when these are used.
	
	* Allow ".length()" to be applied to vectors and matrices, returning 
	  the number of components or columns.
	
	* Allow swizzle operations on scalars.
	
	* Built-in constants for gl_MinProgramTexelOffset and 
	  gl_MaxProgramTexelOffset.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shading_language_420pack.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shading_language_420pack import *
from OpenGL.raw.GL.ARB.shading_language_420pack import _EXTENSION_NAME

def glInitShadingLanguage420PackARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


from OpenGL import platform as _p, constant, extensions
from ctypes import *
from OpenGL.raw.GL._types import *
from OpenGL._bytes import as_8_bit
c_void = None
void = None 
Bool = c_uint

class _GLXQuerier( extensions.ExtensionQuerier ):
    prefix = as_8_bit('GLX_')
    assumed_version = [1,1]
    version_prefix = as_8_bit('GLX_VERSION_GLX_')
    def getDisplay( self ):
        from OpenGL.raw.GLX import _types
        from OpenGL.platform import ctypesloader
        import ctypes, os
        X11 = ctypesloader.loadLibrary( ctypes.cdll, 'X11' )
        XOpenDisplay = X11.XOpenDisplay 
        XOpenDisplay.restype = ctypes.POINTER(_types.Display)
        return XOpenDisplay( os.environ.get( 'DISPLAY' ))
    def getScreen( self, display ):
        from OpenGL.platform import ctypesloader
        from OpenGL.raw.GLX import _types
        import ctypes, os
        X11 = ctypesloader.loadLibrary( ctypes.cdll, 'X11' )
        XDefaultScreen = X11.XDefaultScreen
        XDefaultScreen.argtypes = [ctypes.POINTER(_types.Display)]
        return XDefaultScreen( display )
        
    def pullVersion( self ):
        from OpenGL.GLX import glXQueryVersion
        import ctypes
        if glXQueryVersion:
            display = self.getDisplay()
            major,minor = ctypes.c_int(),ctypes.c_int()
            glXQueryVersion(display, major, minor)
            return [major.value,minor.value]
        else:
            return [1,1]
    def pullExtensions( self ):
        if self.getVersion() >= [1,2]:
            from OpenGL.GLX import glXQueryExtensionsString
            display = self.getDisplay()
            screen = self.getScreen( display )
            
            if glXQueryExtensionsString:
                return glXQueryExtensionsString( display,screen ).split()
        return []
GLXQuerier=_GLXQuerier()


class struct___GLXcontextRec(Structure):
    __slots__ = [
    ]
struct___GLXcontextRec._fields_ = [
    ('_opaque_struct', c_int)
]

class struct___GLXcontextRec(Structure):
    __slots__ = [
    ]
struct___GLXcontextRec._fields_ = [
    ('_opaque_struct', c_int)
]

GLXContext = POINTER(struct___GLXcontextRec) 	# /usr/include/GL/glx.h:178
XID = c_ulong 	# /usr/include/X11/X.h:66
GLXPixmap = XID 	# /usr/include/GL/glx.h:179
GLXDrawable = XID 	# /usr/include/GL/glx.h:180
class struct___GLXFBConfigRec(Structure):
    __slots__ = [
    ]
struct___GLXFBConfigRec._fields_ = [
    ('_opaque_struct', c_int)
]

class struct___GLXFBConfigRec(Structure):
    __slots__ = [
    ]
struct___GLXFBConfigRec._fields_ = [
    ('_opaque_struct', c_int)
]

GLXFBConfig = POINTER(struct___GLXFBConfigRec) 	# /usr/include/GL/glx.h:182
GLXFBConfigID = XID 	# /usr/include/GL/glx.h:183
GLXContextID = XID 	# /usr/include/GL/glx.h:184
GLXWindow = XID 	# /usr/include/GL/glx.h:185
GLXPbuffer = XID 	# /usr/include/GL/glx.h:186
GLXPbufferSGIX = XID
GLXVideoSourceSGIX = XID

class struct_anon_103(Structure):
    __slots__ = [
        'visual',
        'visualid',
        'screen',
        'depth',
        'class',
        'red_mask',
        'green_mask',
        'blue_mask',
        'colormap_size',
        'bits_per_rgb',
    ]
class struct_anon_18(Structure):
    __slots__ = [
        'ext_data',
        'visualid',
        'class',
        'red_mask',
        'green_mask',
        'blue_mask',
        'bits_per_rgb',
        'map_entries',
    ]
class struct__XExtData(Structure):
    __slots__ = [
        'number',
        'next',
        'free_private',
        'private_data',
    ]
XPointer = c_char_p 	# /usr/include/X11/Xlib.h:84
struct__XExtData._fields_ = [
    ('number', c_int),
    ('next', POINTER(struct__XExtData)),
    ('free_private', POINTER(CFUNCTYPE(c_int, POINTER(struct__XExtData)))),
    ('private_data', XPointer),
]

XExtData = struct__XExtData 	# /usr/include/X11/Xlib.h:163
VisualID = c_ulong 	# /usr/include/X11/X.h:76
struct_anon_18._fields_ = [
    ('ext_data', POINTER(XExtData)),
    ('visualid', VisualID),
    ('class', c_int),
    ('red_mask', c_ulong),
    ('green_mask', c_ulong),
    ('blue_mask', c_ulong),
    ('bits_per_rgb', c_int),
    ('map_entries', c_int),
]

Visual = struct_anon_18 	# /usr/include/X11/Xlib.h:246
struct_anon_103._fields_ = [
    ('visual', POINTER(Visual)),
    ('visualid', VisualID),
    ('screen', c_int),
    ('depth', c_int),
    ('class', c_int),
    ('red_mask', c_ulong),
    ('green_mask', c_ulong),
    ('blue_mask', c_ulong),
    ('colormap_size', c_int),
    ('bits_per_rgb', c_int),
]

XVisualInfo = struct_anon_103 	# /usr/include/X11/Xutil.h:294
class struct__XDisplay(Structure):
    __slots__ = [
    ]
struct__XDisplay._fields_ = [
    ('_opaque_struct', c_int)
]

class struct__XDisplay(Structure):
    __slots__ = [
    ]
struct__XDisplay._fields_ = [
    ('_opaque_struct', c_int)
]

Display = struct__XDisplay 	# /usr/include/X11/Xlib.h:495

Pixmap = XID 	# /usr/include/X11/X.h:102
Font = XID 	# /usr/include/X11/X.h:100
Window = XID 	# /usr/include/X11/X.h:96
GLX_ARB_get_proc_address = constant.Constant( 'GLX_ARB_get_proc_address', 1 )
__GLXextFuncPtr = CFUNCTYPE(None) 	# /usr/include/GL/glx.h:330

# EXT_texture_from_pixmap (/usr/include/GL/glx.h:436)
class struct_anon_111(Structure):
    __slots__ = [
        'event_type',
        'draw_type',
        'serial',
        'send_event',
        'display',
        'drawable',
        'buffer_mask',
        'aux_buffer',
        'x',
        'y',
        'width',
        'height',
        'count',
    ]
struct_anon_111._fields_ = [
    ('event_type', c_int),
    ('draw_type', c_int),
    ('serial', c_ulong),
    ('send_event', c_int),
    ('display', POINTER(Display)),
    ('drawable', GLXDrawable),
    ('buffer_mask', c_uint),
    ('aux_buffer', c_uint),
    ('x', c_int),
    ('y', c_int),
    ('width', c_int),
    ('height', c_int),
    ('count', c_int),
]

GLXPbufferClobberEvent = struct_anon_111 	# /usr/include/GL/glx.h:502
class struct_anon_112(Structure):
    __slots__ = [
        'type',
        'serial',
        'send_event',
        'display',
        'drawable',
        'event_type',
        'ust',
        'msc',
        'sbc',
    ]
struct_anon_112._fields_ = [
    ('type', c_int),
    ('serial', c_ulong),
    ('send_event', c_int),
    ('display', POINTER(Display)),
    ('drawable', GLXDrawable),
    ('event_type', c_int),
    ('ust', c_int64),
    ('msc', c_int64),
    ('sbc', c_int64),
]

GLXBufferSwapComplete = struct_anon_112 	# /usr/include/GL/glx.h:514
class struct___GLXEvent(Union):
    __slots__ = [
        'glxpbufferclobber',
        'glxbufferswapcomplete',
        'pad',
    ]
struct___GLXEvent._fields_ = [
    ('glxpbufferclobber', GLXPbufferClobberEvent),
    ('glxbufferswapcomplete', GLXBufferSwapComplete),
    ('pad', c_long * 24),
]

GLXEvent = struct___GLXEvent 	# /usr/include/GL/glx.h:520

class GLXHyperpipeConfigSGIX( Structure ):
    _fields_ = [
        ('pipeName', c_char * 80),
        ('channel',c_int),
        ('participationType',c_uint),
        ('timeSlice',c_int),
    ]




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.WGL import _types as _cs
# End users want this...
from OpenGL.raw.WGL._types import *
from OpenGL.raw.WGL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'WGL_OML_sync_control'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.WGL,'WGL_OML_sync_control',error_checker=_errors._error_checker)

@_f
@_p.types(_cs.BOOL,_cs.HDC,ctypes.POINTER(_cs.INT32),ctypes.POINTER(_cs.INT32))
def wglGetMscRateOML(hdc,numerator,denominator):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,ctypes.POINTER(_cs.INT64),ctypes.POINTER(_cs.INT64),ctypes.POINTER(_cs.INT64))
def wglGetSyncValuesOML(hdc,ust,msc,sbc):pass
@_f
@_p.types(_cs.INT64,_cs.HDC,_cs.INT64,_cs.INT64,_cs.INT64)
def wglSwapBuffersMscOML(hdc,target_msc,divisor,remainder):pass
@_f
@_p.types(_cs.INT64,_cs.HDC,_cs.c_int,_cs.INT64,_cs.INT64,_cs.INT64)
def wglSwapLayerBuffersMscOML(hdc,fuPlanes,target_msc,divisor,remainder):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.INT64,_cs.INT64,_cs.INT64,ctypes.POINTER(_cs.INT64),ctypes.POINTER(_cs.INT64),ctypes.POINTER(_cs.INT64))
def wglWaitForMscOML(hdc,target_msc,divisor,remainder,ust,msc,sbc):pass
@_f
@_p.types(_cs.BOOL,_cs.HDC,_cs.INT64,ctypes.POINTER(_cs.INT64),ctypes.POINTER(_cs.INT64),ctypes.POINTER(_cs.INT64))
def wglWaitForSbcOML(hdc,target_sbc,ust,msc,sbc):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLX import _types as _cs
# End users want this...
from OpenGL.raw.GLX._types import *
from OpenGL.raw.GLX import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLX_NV_present_video'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLX,'GLX_NV_present_video',error_checker=_errors._error_checker)
GLX_NUM_VIDEO_SLOTS_NV=_C('GLX_NUM_VIDEO_SLOTS_NV',0x20F0)
@_f
@_p.types(_cs.c_int,ctypes.POINTER(_cs.Display),_cs.c_uint,_cs.c_uint,ctypes.POINTER(_cs.c_int))
def glXBindVideoDeviceNV(dpy,video_slot,video_device,attrib_list):pass
@_f
@_p.types(ctypes.POINTER(_cs.c_uint),ctypes.POINTER(_cs.Display),_cs.c_int,ctypes.POINTER(_cs.c_int))
def glXEnumerateVideoDevicesNV(dpy,screen,nelements):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_secondary_color'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_secondary_color',error_checker=_errors._error_checker)
GL_COLOR_SUM_EXT=_C('GL_COLOR_SUM_EXT',0x8458)
GL_CURRENT_SECONDARY_COLOR_EXT=_C('GL_CURRENT_SECONDARY_COLOR_EXT',0x8459)
GL_SECONDARY_COLOR_ARRAY_EXT=_C('GL_SECONDARY_COLOR_ARRAY_EXT',0x845E)
GL_SECONDARY_COLOR_ARRAY_POINTER_EXT=_C('GL_SECONDARY_COLOR_ARRAY_POINTER_EXT',0x845D)
GL_SECONDARY_COLOR_ARRAY_SIZE_EXT=_C('GL_SECONDARY_COLOR_ARRAY_SIZE_EXT',0x845A)
GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT=_C('GL_SECONDARY_COLOR_ARRAY_STRIDE_EXT',0x845C)
GL_SECONDARY_COLOR_ARRAY_TYPE_EXT=_C('GL_SECONDARY_COLOR_ARRAY_TYPE_EXT',0x845B)
@_f
@_p.types(None,_cs.GLbyte,_cs.GLbyte,_cs.GLbyte)
def glSecondaryColor3bEXT(red,green,blue):pass
@_f
@_p.types(None,arrays.GLbyteArray)
def glSecondaryColor3bvEXT(v):pass
@_f
@_p.types(None,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glSecondaryColor3dEXT(red,green,blue):pass
@_f
@_p.types(None,arrays.GLdoubleArray)
def glSecondaryColor3dvEXT(v):pass
@_f
@_p.types(None,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glSecondaryColor3fEXT(red,green,blue):pass
@_f
@_p.types(None,arrays.GLfloatArray)
def glSecondaryColor3fvEXT(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLint,_cs.GLint)
def glSecondaryColor3iEXT(red,green,blue):pass
@_f
@_p.types(None,arrays.GLintArray)
def glSecondaryColor3ivEXT(v):pass
@_f
@_p.types(None,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glSecondaryColor3sEXT(red,green,blue):pass
@_f
@_p.types(None,arrays.GLshortArray)
def glSecondaryColor3svEXT(v):pass
@_f
@_p.types(None,_cs.GLubyte,_cs.GLubyte,_cs.GLubyte)
def glSecondaryColor3ubEXT(red,green,blue):pass
@_f
@_p.types(None,arrays.GLubyteArray)
def glSecondaryColor3ubvEXT(v):pass
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLuint)
def glSecondaryColor3uiEXT(red,green,blue):pass
@_f
@_p.types(None,arrays.GLuintArray)
def glSecondaryColor3uivEXT(v):pass
@_f
@_p.types(None,_cs.GLushort,_cs.GLushort,_cs.GLushort)
def glSecondaryColor3usEXT(red,green,blue):pass
@_f
@_p.types(None,arrays.GLushortArray)
def glSecondaryColor3usvEXT(v):pass
@_f
@_p.types(None,_cs.GLint,_cs.GLenum,_cs.GLsizei,ctypes.c_void_p)
def glSecondaryColorPointerEXT(size,type,stride,pointer):pass



"""Wrapper/Implementation of the GLU tessellator objects for PyOpenGL"""
from OpenGL.raw import GLU as _simple
from OpenGL.raw.GL.VERSION import GL_1_1
from OpenGL.platform import createBaseFunction
from OpenGL.GLU import glustruct
from OpenGL import arrays, wrapper
from OpenGL.platform import PLATFORM
GLU = PLATFORM.GLU
from OpenGL.lazywrapper import lazy as _lazy
import ctypes

class GLUtesselator( glustruct.GLUStruct, _simple.GLUtesselator):
    """Implementation class for GLUTessellator structures in OpenGL-ctypes"""
    FUNCTION_TYPE = PLATFORM.functionTypeFor(PLATFORM.GLU)
    CALLBACK_TYPES = {
        # mapping from "which" GLU enumeration to a ctypes function type
        _simple.GLU_TESS_BEGIN: FUNCTION_TYPE( None, _simple.GLenum ),
        _simple.GLU_TESS_BEGIN_DATA: FUNCTION_TYPE(
            None, _simple.GLenum, ctypes.c_void_p
        ),
        _simple.GLU_TESS_EDGE_FLAG: FUNCTION_TYPE( None, _simple.GLboolean),
        _simple.GLU_TESS_EDGE_FLAG_DATA: FUNCTION_TYPE(
            None, _simple.GLboolean, ctypes.c_void_p
        ),
        _simple.GLU_TESS_VERTEX: FUNCTION_TYPE( None, ctypes.c_void_p ),
        _simple.GLU_TESS_VERTEX_DATA: FUNCTION_TYPE(
            None, ctypes.c_void_p, ctypes.c_void_p
        ),
        _simple.GLU_TESS_END: FUNCTION_TYPE( None ),
        _simple.GLU_TESS_END_DATA: FUNCTION_TYPE( None, ctypes.c_void_p),
        _simple.GLU_TESS_COMBINE: FUNCTION_TYPE(
            None,
            ctypes.POINTER(_simple.GLdouble),
            ctypes.POINTER(ctypes.c_void_p),
            ctypes.POINTER(_simple.GLfloat),
            ctypes.POINTER(ctypes.c_void_p)
        ),
        _simple.GLU_TESS_COMBINE_DATA: FUNCTION_TYPE(
            None,
            ctypes.POINTER(_simple.GLdouble),
            ctypes.POINTER(ctypes.c_void_p),
            ctypes.POINTER(_simple.GLfloat),
            ctypes.POINTER(ctypes.c_void_p),
            ctypes.c_void_p,
        ),
        _simple.GLU_TESS_ERROR: FUNCTION_TYPE( None, _simple.GLenum),
        _simple.GLU_TESS_ERROR_DATA: FUNCTION_TYPE(
            None, _simple.GLenum, ctypes.c_void_p
        ),
        _simple.GLU_ERROR : FUNCTION_TYPE( None, _simple.GLenum )
    }
    WRAPPER_METHODS = {
        _simple.GLU_TESS_BEGIN_DATA: 'dataWrapper',
        _simple.GLU_TESS_EDGE_FLAG_DATA: 'dataWrapper',
        _simple.GLU_TESS_VERTEX: 'vertexWrapper',
        _simple.GLU_TESS_VERTEX_DATA: 'vertexWrapper',
        _simple.GLU_TESS_END_DATA: 'dataWrapper',
        _simple.GLU_TESS_COMBINE: 'combineWrapper',
        _simple.GLU_TESS_COMBINE_DATA: 'combineWrapper',
        _simple.GLU_TESS_ERROR_DATA: 'dataWrapper',
    }
    def gluTessVertex( self, location, data=None ):
        """Add a vertex to this tessellator, storing data for later lookup"""
        vertexCache = getattr( self, 'vertexCache', None )
        if vertexCache is None:
            self.vertexCache = []
            vertexCache = self.vertexCache
        location = arrays.GLdoubleArray.asArray( location, GL_1_1.GL_DOUBLE )
        if arrays.GLdoubleArray.arraySize( location ) != 3:
            raise ValueError( """Require 3 doubles for array location, got: %s"""%(location,))
        oorValue = self.noteObject(data)
        vp = ctypes.c_void_p( oorValue )
        self.vertexCache.append( location )
        return gluTessVertexBase( self, location, vp )
    def gluTessBeginPolygon( self, data ):
        """Note the object pointer to return it as a Python object"""
        return _simple.gluTessBeginPolygon(
            self, ctypes.c_void_p(self.noteObject( data ))
        )
    def combineWrapper( self, function ):
        """Wrap a Python function with ctypes-compatible wrapper for combine callback

        For a Python combine callback, the signature looks like this:
            def combine(
                GLdouble coords[3],
                void *vertex_data[4],
                GLfloat weight[4]
            ):
                return data
        While the C signature looks like this:
            void combine(
                GLdouble coords[3],
                void *vertex_data[4],
                GLfloat weight[4],
                void **outData
            )
        """
        if (function is not None) and (not hasattr( function,'__call__' )):
            raise TypeError( """Require a callable callback, got:  %s"""%(function,))
        def wrap( coords, vertex_data, weight, outData, *args ):
            """The run-time wrapper around the function"""
            coords = self.ptrAsArray( coords, 3, arrays.GLdoubleArray )
            weight = self.ptrAsArray( weight, 4, arrays.GLfloatArray )
            # find the original python objects for vertex data
            vertex_data = [ self.originalObject( vertex_data[i] ) for i in range(4) ]
            args = tuple( [ self.originalObject( x ) for x in args ] )
            try:
                result = function( coords, vertex_data, weight, *args )
            except Exception as err:
                raise err.__class__(
                    """Failure during combine callback %r with args( %s,%s,%s,*%s):\n%s"""%(
                        function, coords, vertex_data, weight, args, str(err),
                    )
                )
            outP = ctypes.c_void_p(self.noteObject(result))
            if outData:
                outData[0] = outP
            else:
                raise RuntimeError( "Null outData passed to callback" )
            return None
        return wrap
    def dataWrapper( self, function ):
        """Wrap a function which only has the one data-pointer as last arg"""
        if (function is not None) and (not hasattr( function,'__call__' )):
            raise TypeError( """Require a callable callback, got:  %s"""%(function,))
        def wrap( *args ):
            """Just return the original object for polygon_data"""
            args = args[:-1] + ( self.originalObject(args[-1]), )
            try:
                return function( *args )
            except Exception as err:
                err.args += (function,args)
                raise
        return wrap
    def dataWrapper2( self, function ):
        """Wrap a function which has two data-pointers as last args"""
        if (function is not None) and (not hasattr( function,'__call__' )):
            raise TypeError( """Require a callable callback, got:  %s"""%(function,))
        def wrap( *args ):
            """Just return the original object for polygon_data"""
            args = args[:-2] + ( self.originalObject(args[-2]), self.originalObject(args[-1]), )
            try:
                return function( *args )
            except Exception as err:
                err.args += (function,args)
                raise
        return wrap
    def vertexWrapper( self, function ):
        """Converts a vertex-pointer into an OOR vertex for processing"""
        if (function is not None) and (not hasattr( function,'__call__' )):
            raise TypeError( """Require a callable callback, got:  %s"""%(function,))
        def wrap( vertex, data=None ):
            """Just return the original object for polygon_data"""
            vertex = self.originalObject(vertex)
            try:
                if data is not None:
                    data = self.originalObject(data)
                    return function( vertex, data )
                else:
                    return function( vertex )
            except Exception as err:
                err.args += (function,(vertex,data))
                raise
        return wrap

GLUtesselator.CALLBACK_FUNCTION_REGISTRARS = dict([
    (c,createBaseFunction(
        'gluTessCallback', dll=GLU, resultType=None,
        argTypes=[ctypes.POINTER(GLUtesselator), _simple.GLenum,funcType],
        doc='gluTessCallback( POINTER(GLUtesselator)(tess), GLenum(which), _GLUfuncptr(CallBackFunc) ) -> None',
        argNames=('tess', 'which', 'CallBackFunc'),
    ))
    for (c,funcType) in GLUtesselator.CALLBACK_TYPES.items()
])
try:
    del c, funcType
except NameError as err:
    pass

def gluTessCallback( tess, which, function ):
    """Set a given gluTessellator callback for the given tessellator"""
    return tess.addCallback( which, function )
def gluTessBeginPolygon( tess, data ):
    """Start definition of polygon in the tessellator"""
    return tess.gluTessBeginPolygon( data )
def gluTessVertex( tess, location, data=None ):
    """Add a vertex to the tessellator's current polygon"""
    return tess.gluTessVertex( location, data )

# /usr/include/GL/glu.h 293
@_lazy(
    createBaseFunction(
        'gluNewTess', dll=GLU, resultType=ctypes.POINTER(GLUtesselator),
        doc='gluNewTess(  ) -> POINTER(GLUtesselator)',
    )
)
def gluNewTess( baseFunction ):
    """Get a new tessellator object (just unpacks the pointer for you)"""
    return baseFunction()[0]

@_lazy( _simple.gluGetTessProperty )
def gluGetTessProperty( baseFunction, tess, which, data=None ):
    """Retrieve single double for a tessellator property"""
    if data is None:
        data = _simple.GLdouble( 0.0 )
        baseFunction( tess, which, data )
        return data.value
    else:
        return baseFunction( tess, which, data )

gluTessVertexBase = wrapper.wrapper( _simple.gluTessVertex ).setInputArraySize(
    'location',
    3,
)

__all__ = (
    'gluNewTess',
    'gluGetTessProperty',
    'gluTessBeginPolygon',
    'gluTessCallback',
    'gluTessVertex',
)



'''OpenGL extension EXT.texture_object

This module customises the behaviour of the 
OpenGL.raw.GL.EXT.texture_object to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension introduces named texture objects.  The only way to name
	a texture in GL 1.0 is by defining it as a single display list.  Because
	display lists cannot be edited, these objects are static.  Yet it is
	important to be able to change the images and parameters of a texture.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/EXT/texture_object.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.EXT.texture_object import *
from OpenGL.raw.GL.EXT.texture_object import _EXTENSION_NAME

def glInitTextureObjectEXT():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glAreTexturesResidentEXT.textures size not checked against n
glAreTexturesResidentEXT=wrapper.wrapper(glAreTexturesResidentEXT).setOutput(
    'residences',size=lambda x:(x,),pnameArg='n',orPassIn=True
).setInputArraySize(
    'textures', None
)
# INPUT glDeleteTexturesEXT.textures size not checked against n
glDeleteTexturesEXT=wrapper.wrapper(glDeleteTexturesEXT).setInputArraySize(
    'textures', None
)
glGenTexturesEXT=wrapper.wrapper(glGenTexturesEXT).setOutput(
    'textures',size=lambda x:(x,),pnameArg='n',orPassIn=True
)
# INPUT glPrioritizeTexturesEXT.priorities size not checked against n
# INPUT glPrioritizeTexturesEXT.textures size not checked against n
glPrioritizeTexturesEXT=wrapper.wrapper(glPrioritizeTexturesEXT).setInputArraySize(
    'priorities', None
).setInputArraySize(
    'textures', None
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_EXT_shader_image_load_store'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_EXT_shader_image_load_store',error_checker=_errors._error_checker)
GL_ALL_BARRIER_BITS_EXT=_C('GL_ALL_BARRIER_BITS_EXT',0xFFFFFFFF)
GL_ATOMIC_COUNTER_BARRIER_BIT_EXT=_C('GL_ATOMIC_COUNTER_BARRIER_BIT_EXT',0x00001000)
GL_BUFFER_UPDATE_BARRIER_BIT_EXT=_C('GL_BUFFER_UPDATE_BARRIER_BIT_EXT',0x00000200)
GL_COMMAND_BARRIER_BIT_EXT=_C('GL_COMMAND_BARRIER_BIT_EXT',0x00000040)
GL_ELEMENT_ARRAY_BARRIER_BIT_EXT=_C('GL_ELEMENT_ARRAY_BARRIER_BIT_EXT',0x00000002)
GL_FRAMEBUFFER_BARRIER_BIT_EXT=_C('GL_FRAMEBUFFER_BARRIER_BIT_EXT',0x00000400)
GL_IMAGE_1D_ARRAY_EXT=_C('GL_IMAGE_1D_ARRAY_EXT',0x9052)
GL_IMAGE_1D_EXT=_C('GL_IMAGE_1D_EXT',0x904C)
GL_IMAGE_2D_ARRAY_EXT=_C('GL_IMAGE_2D_ARRAY_EXT',0x9053)
GL_IMAGE_2D_EXT=_C('GL_IMAGE_2D_EXT',0x904D)
GL_IMAGE_2D_MULTISAMPLE_ARRAY_EXT=_C('GL_IMAGE_2D_MULTISAMPLE_ARRAY_EXT',0x9056)
GL_IMAGE_2D_MULTISAMPLE_EXT=_C('GL_IMAGE_2D_MULTISAMPLE_EXT',0x9055)
GL_IMAGE_2D_RECT_EXT=_C('GL_IMAGE_2D_RECT_EXT',0x904F)
GL_IMAGE_3D_EXT=_C('GL_IMAGE_3D_EXT',0x904E)
GL_IMAGE_BINDING_ACCESS_EXT=_C('GL_IMAGE_BINDING_ACCESS_EXT',0x8F3E)
GL_IMAGE_BINDING_FORMAT_EXT=_C('GL_IMAGE_BINDING_FORMAT_EXT',0x906E)
GL_IMAGE_BINDING_LAYERED_EXT=_C('GL_IMAGE_BINDING_LAYERED_EXT',0x8F3C)
GL_IMAGE_BINDING_LAYER_EXT=_C('GL_IMAGE_BINDING_LAYER_EXT',0x8F3D)
GL_IMAGE_BINDING_LEVEL_EXT=_C('GL_IMAGE_BINDING_LEVEL_EXT',0x8F3B)
GL_IMAGE_BINDING_NAME_EXT=_C('GL_IMAGE_BINDING_NAME_EXT',0x8F3A)
GL_IMAGE_BUFFER_EXT=_C('GL_IMAGE_BUFFER_EXT',0x9051)
GL_IMAGE_CUBE_EXT=_C('GL_IMAGE_CUBE_EXT',0x9050)
GL_IMAGE_CUBE_MAP_ARRAY_EXT=_C('GL_IMAGE_CUBE_MAP_ARRAY_EXT',0x9054)
GL_INT_IMAGE_1D_ARRAY_EXT=_C('GL_INT_IMAGE_1D_ARRAY_EXT',0x905D)
GL_INT_IMAGE_1D_EXT=_C('GL_INT_IMAGE_1D_EXT',0x9057)
GL_INT_IMAGE_2D_ARRAY_EXT=_C('GL_INT_IMAGE_2D_ARRAY_EXT',0x905E)
GL_INT_IMAGE_2D_EXT=_C('GL_INT_IMAGE_2D_EXT',0x9058)
GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT=_C('GL_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT',0x9061)
GL_INT_IMAGE_2D_MULTISAMPLE_EXT=_C('GL_INT_IMAGE_2D_MULTISAMPLE_EXT',0x9060)
GL_INT_IMAGE_2D_RECT_EXT=_C('GL_INT_IMAGE_2D_RECT_EXT',0x905A)
GL_INT_IMAGE_3D_EXT=_C('GL_INT_IMAGE_3D_EXT',0x9059)
GL_INT_IMAGE_BUFFER_EXT=_C('GL_INT_IMAGE_BUFFER_EXT',0x905C)
GL_INT_IMAGE_CUBE_EXT=_C('GL_INT_IMAGE_CUBE_EXT',0x905B)
GL_INT_IMAGE_CUBE_MAP_ARRAY_EXT=_C('GL_INT_IMAGE_CUBE_MAP_ARRAY_EXT',0x905F)
GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS_EXT=_C('GL_MAX_COMBINED_IMAGE_UNITS_AND_FRAGMENT_OUTPUTS_EXT',0x8F39)
GL_MAX_IMAGE_SAMPLES_EXT=_C('GL_MAX_IMAGE_SAMPLES_EXT',0x906D)
GL_MAX_IMAGE_UNITS_EXT=_C('GL_MAX_IMAGE_UNITS_EXT',0x8F38)
GL_PIXEL_BUFFER_BARRIER_BIT_EXT=_C('GL_PIXEL_BUFFER_BARRIER_BIT_EXT',0x00000080)
GL_SHADER_IMAGE_ACCESS_BARRIER_BIT_EXT=_C('GL_SHADER_IMAGE_ACCESS_BARRIER_BIT_EXT',0x00000020)
GL_TEXTURE_FETCH_BARRIER_BIT_EXT=_C('GL_TEXTURE_FETCH_BARRIER_BIT_EXT',0x00000008)
GL_TEXTURE_UPDATE_BARRIER_BIT_EXT=_C('GL_TEXTURE_UPDATE_BARRIER_BIT_EXT',0x00000100)
GL_TRANSFORM_FEEDBACK_BARRIER_BIT_EXT=_C('GL_TRANSFORM_FEEDBACK_BARRIER_BIT_EXT',0x00000800)
GL_UNIFORM_BARRIER_BIT_EXT=_C('GL_UNIFORM_BARRIER_BIT_EXT',0x00000004)
GL_UNSIGNED_INT_IMAGE_1D_ARRAY_EXT=_C('GL_UNSIGNED_INT_IMAGE_1D_ARRAY_EXT',0x9068)
GL_UNSIGNED_INT_IMAGE_1D_EXT=_C('GL_UNSIGNED_INT_IMAGE_1D_EXT',0x9062)
GL_UNSIGNED_INT_IMAGE_2D_ARRAY_EXT=_C('GL_UNSIGNED_INT_IMAGE_2D_ARRAY_EXT',0x9069)
GL_UNSIGNED_INT_IMAGE_2D_EXT=_C('GL_UNSIGNED_INT_IMAGE_2D_EXT',0x9063)
GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT=_C('GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_ARRAY_EXT',0x906C)
GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_EXT=_C('GL_UNSIGNED_INT_IMAGE_2D_MULTISAMPLE_EXT',0x906B)
GL_UNSIGNED_INT_IMAGE_2D_RECT_EXT=_C('GL_UNSIGNED_INT_IMAGE_2D_RECT_EXT',0x9065)
GL_UNSIGNED_INT_IMAGE_3D_EXT=_C('GL_UNSIGNED_INT_IMAGE_3D_EXT',0x9064)
GL_UNSIGNED_INT_IMAGE_BUFFER_EXT=_C('GL_UNSIGNED_INT_IMAGE_BUFFER_EXT',0x9067)
GL_UNSIGNED_INT_IMAGE_CUBE_EXT=_C('GL_UNSIGNED_INT_IMAGE_CUBE_EXT',0x9066)
GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_EXT=_C('GL_UNSIGNED_INT_IMAGE_CUBE_MAP_ARRAY_EXT',0x906A)
GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT_EXT=_C('GL_VERTEX_ATTRIB_ARRAY_BARRIER_BIT_EXT',0x00000001)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLint,_cs.GLboolean,_cs.GLint,_cs.GLenum,_cs.GLint)
def glBindImageTextureEXT(index,texture,level,layered,layer,access,format):pass
@_f
@_p.types(None,_cs.GLbitfield)
def glMemoryBarrierEXT(barriers):pass



'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_shader_atomic_counters'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_shader_atomic_counters',error_checker=_errors._error_checker)
GL_ACTIVE_ATOMIC_COUNTER_BUFFERS=_C('GL_ACTIVE_ATOMIC_COUNTER_BUFFERS',0x92D9)
GL_ATOMIC_COUNTER_BUFFER=_C('GL_ATOMIC_COUNTER_BUFFER',0x92C0)
GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS=_C('GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTERS',0x92C5)
GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES=_C('GL_ATOMIC_COUNTER_BUFFER_ACTIVE_ATOMIC_COUNTER_INDICES',0x92C6)
GL_ATOMIC_COUNTER_BUFFER_BINDING=_C('GL_ATOMIC_COUNTER_BUFFER_BINDING',0x92C1)
GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE=_C('GL_ATOMIC_COUNTER_BUFFER_DATA_SIZE',0x92C4)
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER=_C('GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_FRAGMENT_SHADER',0x92CB)
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER=_C('GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_GEOMETRY_SHADER',0x92CA)
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER=_C('GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_CONTROL_SHADER',0x92C8)
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER=_C('GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_TESS_EVALUATION_SHADER',0x92C9)
GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER=_C('GL_ATOMIC_COUNTER_BUFFER_REFERENCED_BY_VERTEX_SHADER',0x92C7)
GL_ATOMIC_COUNTER_BUFFER_SIZE=_C('GL_ATOMIC_COUNTER_BUFFER_SIZE',0x92C3)
GL_ATOMIC_COUNTER_BUFFER_START=_C('GL_ATOMIC_COUNTER_BUFFER_START',0x92C2)
GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS=_C('GL_MAX_ATOMIC_COUNTER_BUFFER_BINDINGS',0x92DC)
GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE=_C('GL_MAX_ATOMIC_COUNTER_BUFFER_SIZE',0x92D8)
GL_MAX_COMBINED_ATOMIC_COUNTERS=_C('GL_MAX_COMBINED_ATOMIC_COUNTERS',0x92D7)
GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_COMBINED_ATOMIC_COUNTER_BUFFERS',0x92D1)
GL_MAX_FRAGMENT_ATOMIC_COUNTERS=_C('GL_MAX_FRAGMENT_ATOMIC_COUNTERS',0x92D6)
GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_FRAGMENT_ATOMIC_COUNTER_BUFFERS',0x92D0)
GL_MAX_GEOMETRY_ATOMIC_COUNTERS=_C('GL_MAX_GEOMETRY_ATOMIC_COUNTERS',0x92D5)
GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_GEOMETRY_ATOMIC_COUNTER_BUFFERS',0x92CF)
GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS=_C('GL_MAX_TESS_CONTROL_ATOMIC_COUNTERS',0x92D3)
GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_TESS_CONTROL_ATOMIC_COUNTER_BUFFERS',0x92CD)
GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS=_C('GL_MAX_TESS_EVALUATION_ATOMIC_COUNTERS',0x92D4)
GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_TESS_EVALUATION_ATOMIC_COUNTER_BUFFERS',0x92CE)
GL_MAX_VERTEX_ATOMIC_COUNTERS=_C('GL_MAX_VERTEX_ATOMIC_COUNTERS',0x92D2)
GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS=_C('GL_MAX_VERTEX_ATOMIC_COUNTER_BUFFERS',0x92CC)
GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX=_C('GL_UNIFORM_ATOMIC_COUNTER_BUFFER_INDEX',0x92DA)
GL_UNSIGNED_INT_ATOMIC_COUNTER=_C('GL_UNSIGNED_INT_ATOMIC_COUNTER',0x92DB)
@_f
@_p.types(None,_cs.GLuint,_cs.GLuint,_cs.GLenum,arrays.GLintArray)
def glGetActiveAtomicCounterBufferiv(program,bufferIndex,pname,params):pass



'''OpenGL extension ARB.map_buffer_range

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.map_buffer_range to provide a more 
Python-friendly API

Overview (from the spec)
	
	ARB_map_buffer_range expands the buffer object API to allow greater
	performance when a client application only needs to write to a sub-range
	of a buffer object. To that end, this extension introduces two new buffer
	object features: non-serialized buffer modification and explicit sub-range
	flushing for mapped buffer objects.
	
	OpenGL requires that commands occur in a FIFO manner meaning that any
	changes to buffer objects either block until the data has been processed by
	the OpenGL pipeline or else create extra copies to avoid such a block.  By
	providing a method to asynchronously modify buffer object data, an
	application is then able to manage the synchronization points themselves
	and modify ranges of data contained by a buffer object even though OpenGL
	might still be using other parts of it.
	
	This extension also provides a method for explicitly flushing ranges of a
	mapped buffer object so OpenGL does not have to assume that the entire
	range may have been modified.  Further, it allows the application to more
	precisely specify its intent with respect to reading, writing, and whether
	the previous contents of a mapped range of interest need be preserved
	prior to modification.
	
	Affects ARB_vertex_buffer_object, ARB_pixel_buffer_object and OpenGL 1.5
	Buffer Objects.
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/map_buffer_range.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.map_buffer_range import *
from OpenGL.raw.GL.ARB.map_buffer_range import _EXTENSION_NAME

def glInitMapBufferRangeARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension AMD.conservative_depth

This module customises the behaviour of the 
OpenGL.raw.GL.AMD.conservative_depth to provide a more 
Python-friendly API

Overview (from the spec)
	
	There is a common optimization for hardware accelerated implementation of
	OpenGL which relies on an early depth test to be run before the fragment
	shader so that the shader evaluation can be skipped if the fragment ends
	up being discarded because it is occluded.
	
	This optimization does not affect the final rendering, and is typically
	possible when the fragment does not change the depth programmatically.
	(i.e.: it does not write to the built-in gl_FragDepth output). There are,
	however a class of operations on the depth in the shader which could
	still be performed while allowing the early depth test to operate.
	
	This extension allows the application to pass enough information to the
	GL implementation to activate such optimizations safely.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/AMD/conservative_depth.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.AMD.conservative_depth import *
from OpenGL.raw.GL.AMD.conservative_depth import _EXTENSION_NAME

def glInitConservativeDepthAMD():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_SGIX_polynomial_ffd'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_SGIX_polynomial_ffd',error_checker=_errors._error_checker)
GL_DEFORMATIONS_MASK_SGIX=_C('GL_DEFORMATIONS_MASK_SGIX',0x8196)
GL_GEOMETRY_DEFORMATION_BIT_SGIX=_C('GL_GEOMETRY_DEFORMATION_BIT_SGIX',0x00000002)
GL_GEOMETRY_DEFORMATION_SGIX=_C('GL_GEOMETRY_DEFORMATION_SGIX',0x8194)
GL_MAX_DEFORMATION_ORDER_SGIX=_C('GL_MAX_DEFORMATION_ORDER_SGIX',0x8197)
GL_TEXTURE_DEFORMATION_BIT_SGIX=_C('GL_TEXTURE_DEFORMATION_BIT_SGIX',0x00000001)
GL_TEXTURE_DEFORMATION_SGIX=_C('GL_TEXTURE_DEFORMATION_SGIX',0x8195)
@_f
@_p.types(None,_cs.GLbitfield)
def glDeformSGIX(mask):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,_cs.GLdouble,_cs.GLdouble,_cs.GLint,_cs.GLint,arrays.GLdoubleArray)
def glDeformationMap3dSGIX(target,u1,u2,ustride,uorder,v1,v2,vstride,vorder,w1,w2,wstride,worder,points):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,_cs.GLfloat,_cs.GLfloat,_cs.GLint,_cs.GLint,arrays.GLfloatArray)
def glDeformationMap3fSGIX(target,u1,u2,ustride,uorder,v1,v2,vstride,vorder,w1,w2,wstride,worder,points):pass
@_f
@_p.types(None,_cs.GLbitfield)
def glLoadIdentityDeformationMapSGIX(mask):pass



'''OpenGL extension VERSION.GL_1_4

This module customises the behaviour of the 
OpenGL.raw.GL.VERSION.GL_1_4 to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/VERSION/GL_1_4.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.VERSION.GL_1_4 import *
from OpenGL.raw.GL.VERSION.GL_1_4 import _EXTENSION_NAME

def glInitGl14VERSION():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glMultiDrawArrays.count size not checked against 'drawcount'
# INPUT glMultiDrawArrays.first size not checked against 'count'
glMultiDrawArrays=wrapper.wrapper(glMultiDrawArrays).setInputArraySize(
    'count', None
).setInputArraySize(
    'first', None
)
# INPUT glMultiDrawElements.count size not checked against 'drawcount'
# INPUT glMultiDrawElements.indices size not checked against 'drawcount'
glMultiDrawElements=wrapper.wrapper(glMultiDrawElements).setInputArraySize(
    'count', None
).setInputArraySize(
    'indices', None
)
# INPUT glPointParameterfv.params size not checked against 'pname'
glPointParameterfv=wrapper.wrapper(glPointParameterfv).setInputArraySize(
    'params', None
)
# INPUT glPointParameteriv.params size not checked against 'pname'
glPointParameteriv=wrapper.wrapper(glPointParameteriv).setInputArraySize(
    'params', None
)
glFogCoordfv=wrapper.wrapper(glFogCoordfv).setInputArraySize(
    'coord', 1
)
glFogCoorddv=wrapper.wrapper(glFogCoorddv).setInputArraySize(
    'coord', 1
)
# INPUT glFogCoordPointer.pointer size not checked against 'type,stride'
glFogCoordPointer=wrapper.wrapper(glFogCoordPointer).setInputArraySize(
    'pointer', None
)
glSecondaryColor3bv=wrapper.wrapper(glSecondaryColor3bv).setInputArraySize(
    'v', 3
)
glSecondaryColor3dv=wrapper.wrapper(glSecondaryColor3dv).setInputArraySize(
    'v', 3
)
glSecondaryColor3fv=wrapper.wrapper(glSecondaryColor3fv).setInputArraySize(
    'v', 3
)
glSecondaryColor3iv=wrapper.wrapper(glSecondaryColor3iv).setInputArraySize(
    'v', 3
)
glSecondaryColor3sv=wrapper.wrapper(glSecondaryColor3sv).setInputArraySize(
    'v', 3
)
glSecondaryColor3ubv=wrapper.wrapper(glSecondaryColor3ubv).setInputArraySize(
    'v', 3
)
glSecondaryColor3uiv=wrapper.wrapper(glSecondaryColor3uiv).setInputArraySize(
    'v', 3
)
glSecondaryColor3usv=wrapper.wrapper(glSecondaryColor3usv).setInputArraySize(
    'v', 3
)
# INPUT glSecondaryColorPointer.pointer size not checked against 'size,type,stride'
glSecondaryColorPointer=wrapper.wrapper(glSecondaryColorPointer).setInputArraySize(
    'pointer', None
)
glWindowPos2dv=wrapper.wrapper(glWindowPos2dv).setInputArraySize(
    'v', 2
)
glWindowPos2fv=wrapper.wrapper(glWindowPos2fv).setInputArraySize(
    'v', 2
)
glWindowPos2iv=wrapper.wrapper(glWindowPos2iv).setInputArraySize(
    'v', 2
)
glWindowPos2sv=wrapper.wrapper(glWindowPos2sv).setInputArraySize(
    'v', 2
)
glWindowPos3dv=wrapper.wrapper(glWindowPos3dv).setInputArraySize(
    'v', 3
)
glWindowPos3fv=wrapper.wrapper(glWindowPos3fv).setInputArraySize(
    'v', 3
)
glWindowPos3iv=wrapper.wrapper(glWindowPos3iv).setInputArraySize(
    'v', 3
)
glWindowPos3sv=wrapper.wrapper(glWindowPos3sv).setInputArraySize(
    'v', 3
)
### END AUTOGENERATED SECTION
GL_CURRENT_FOG_COORD = GL_CURRENT_FOG_COORDINATE # alias
GL_FOG_COORD = GL_FOG_COORDINATE # alias
GL_FOG_COORD_ARRAY = GL_FOG_COORDINATE_ARRAY # alias
GL_FOG_COORD_ARRAY_POINTER = GL_FOG_COORDINATE_ARRAY_POINTER # alias
GL_FOG_COORD_ARRAY_STRIDE = GL_FOG_COORDINATE_ARRAY_STRIDE # alias
GL_FOG_COORD_ARRAY_TYPE = GL_FOG_COORDINATE_ARRAY_TYPE # alias
GL_FOG_COORD_SRC = GL_FOG_COORDINATE_SOURCE # alias



'''OpenGL extension ARB.shader_atomic_counters

This module customises the behaviour of the 
OpenGL.raw.GL.ARB.shader_atomic_counters to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension provides a set of atomic counters.
	
	This extension provides GLSL built-in functions to
	query and increment/decrement these atomic counters.
	
	This enables a shader to write to unique offsets
	(append to a buffer object) or read from unique offsets
	(consume from a buffer object).
	
	Opaque handles to atomic counters are declared
	at global scope and are qualified with the uniform qualifier.
	
	Unlike other user-defined uniforms declared at global scope,
	they take NO storage from the default partition, they have
	NO location, and they may NOT be set with the Uniform* commands.
	Atomic counters may also NOT be grouped into uniform blocks.
	
	Active atomic counters can be discovered by the commands
	GetUniformIndices, GetActiveUniformName, GetActiveUniform
	and GetActiveUniformsiv.
	
	Like samplers, the opaque handles of the atomic counters
	and are ONLY used in some GLSL built-in functions.
	
	The atomic counters pointed to by the opaque handles
	are bound to buffer binding points and buffer offsets
	through the layout qualifiers in the shading language,
	or they are implicitly assigned by the compiler.
	
	Through the OpenGL API, buffer objects may be
	bound to these binding points with BindBufferBase
	or BindBufferRange.
	
	The contents of the atomic counters are stored
	in the buffer objects.  The contents of atomic
	counters may be set and queried with buffer object
	manipulation functions (e.g. BufferData,
	BufferSubData, MapBuffer or MapBufferRange).
	

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/ARB/shader_atomic_counters.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.ARB.shader_atomic_counters import *
from OpenGL.raw.GL.ARB.shader_atomic_counters import _EXTENSION_NAME

def glInitShaderAtomicCountersARB():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

glGetActiveAtomicCounterBufferiv=wrapper.wrapper(glGetActiveAtomicCounterBufferiv).setOutput(
    'params',size=_glgets._glget_size_mapping,pnameArg='pname',orPassIn=True
)
### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GLES1 import _types as _cs
# End users want this...
from OpenGL.raw.GLES1._types import *
from OpenGL.raw.GLES1 import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GLES1_EXT_texture_compression_dxt1'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GLES1,'GLES1_EXT_texture_compression_dxt1',error_checker=_errors._error_checker)
GL_COMPRESSED_RGBA_S3TC_DXT1_EXT=_C('GL_COMPRESSED_RGBA_S3TC_DXT1_EXT',0x83F1)
GL_COMPRESSED_RGB_S3TC_DXT1_EXT=_C('GL_COMPRESSED_RGB_S3TC_DXT1_EXT',0x83F0)




'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_AMD_query_buffer_object'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_AMD_query_buffer_object',error_checker=_errors._error_checker)
GL_QUERY_BUFFER_AMD=_C('GL_QUERY_BUFFER_AMD',0x9192)
GL_QUERY_BUFFER_BINDING_AMD=_C('GL_QUERY_BUFFER_BINDING_AMD',0x9193)
GL_QUERY_RESULT_NO_WAIT_AMD=_C('GL_QUERY_RESULT_NO_WAIT_AMD',0x9194)




'''OpenGL extension NV.bindless_texture

This module customises the behaviour of the 
OpenGL.raw.GLES2.NV.bindless_texture to provide a more 
Python-friendly API

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/bindless_texture.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GLES2 import _types, _glgets
from OpenGL.raw.GLES2.NV.bindless_texture import *
from OpenGL.raw.GLES2.NV.bindless_texture import _EXTENSION_NAME

def glInitBindlessTextureNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )

# INPUT glUniformHandleui64vNV.value size not checked against count
glUniformHandleui64vNV=wrapper.wrapper(glUniformHandleui64vNV).setInputArraySize(
    'value', None
)
# INPUT glProgramUniformHandleui64vNV.values size not checked against count
glProgramUniformHandleui64vNV=wrapper.wrapper(glProgramUniformHandleui64vNV).setInputArraySize(
    'values', None
)
### END AUTOGENERATED SECTION


'''OpenGL extension MESA.resize_buffers

This module customises the behaviour of the 
OpenGL.raw.GL.MESA.resize_buffers to provide a more 
Python-friendly API

Overview (from the spec)
	
	Mesa is often used as a client library with no integration with
	the computer's window system (an X server, for example).  And since
	Mesa does not have an event loop nor window system callbacks, it
	cannot properly respond to window system events.  In particular,
	Mesa cannot automatically detect when a window has been resized.
	
	Mesa's glViewport command queries the current window size and updates
	its internal data structors accordingly.  This normally works fine
	since most applications call glViewport in responce to window size
	changes.
	
	In some situations, however, the application may not call glViewport
	when a window size changes but would still like Mesa to adjust to
	the new window size.  This extension exports a new function to solve
	this problem.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/MESA/resize_buffers.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.GL import _types, _glgets
from OpenGL.raw.GL.MESA.resize_buffers import *
from OpenGL.raw.GL.MESA.resize_buffers import _EXTENSION_NAME

def glInitResizeBuffersMESA():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''OpenGL extension NV.DX_interop

This module customises the behaviour of the 
OpenGL.raw.WGL.NV.DX_interop to provide a more 
Python-friendly API

Overview (from the spec)
	
	This extension allows OpenGL to directly access DirectX buffers
	and surfaces.  A DirectX vertex buffer may be shared as an OpenGL
	buffer object and a DirectX surface may be shared as an OpenGL
	texture or renderbuffer object.

The official definition of this extension is available here:
http://www.opengl.org/registry/specs/NV/DX_interop.txt
'''
from OpenGL import platform, constant, arrays
from OpenGL import extensions, wrapper
import ctypes
from OpenGL.raw.WGL import _types, _glgets
from OpenGL.raw.WGL.NV.DX_interop import *
from OpenGL.raw.WGL.NV.DX_interop import _EXTENSION_NAME

def glInitDxInteropNV():
    '''Return boolean indicating whether this extension is available'''
    from OpenGL import extensions
    return extensions.hasGLExtension( _EXTENSION_NAME )


### END AUTOGENERATED SECTION


'''Autogenerated by xml_generate script, do not edit!'''
from OpenGL import platform as _p, arrays
# Code generation uses this
from OpenGL.raw.GL import _types as _cs
# End users want this...
from OpenGL.raw.GL._types import *
from OpenGL.raw.GL import _errors
from OpenGL.constant import Constant as _C

import ctypes
_EXTENSION_NAME = 'GL_ARB_multitexture'
def _f( function ):
    return _p.createFunction( function,_p.PLATFORM.GL,'GL_ARB_multitexture',error_checker=_errors._error_checker)
GL_ACTIVE_TEXTURE_ARB=_C('GL_ACTIVE_TEXTURE_ARB',0x84E0)
GL_CLIENT_ACTIVE_TEXTURE_ARB=_C('GL_CLIENT_ACTIVE_TEXTURE_ARB',0x84E1)
GL_MAX_TEXTURE_UNITS_ARB=_C('GL_MAX_TEXTURE_UNITS_ARB',0x84E2)
GL_TEXTURE0_ARB=_C('GL_TEXTURE0_ARB',0x84C0)
GL_TEXTURE10_ARB=_C('GL_TEXTURE10_ARB',0x84CA)
GL_TEXTURE11_ARB=_C('GL_TEXTURE11_ARB',0x84CB)
GL_TEXTURE12_ARB=_C('GL_TEXTURE12_ARB',0x84CC)
GL_TEXTURE13_ARB=_C('GL_TEXTURE13_ARB',0x84CD)
GL_TEXTURE14_ARB=_C('GL_TEXTURE14_ARB',0x84CE)
GL_TEXTURE15_ARB=_C('GL_TEXTURE15_ARB',0x84CF)
GL_TEXTURE16_ARB=_C('GL_TEXTURE16_ARB',0x84D0)
GL_TEXTURE17_ARB=_C('GL_TEXTURE17_ARB',0x84D1)
GL_TEXTURE18_ARB=_C('GL_TEXTURE18_ARB',0x84D2)
GL_TEXTURE19_ARB=_C('GL_TEXTURE19_ARB',0x84D3)
GL_TEXTURE1_ARB=_C('GL_TEXTURE1_ARB',0x84C1)
GL_TEXTURE20_ARB=_C('GL_TEXTURE20_ARB',0x84D4)
GL_TEXTURE21_ARB=_C('GL_TEXTURE21_ARB',0x84D5)
GL_TEXTURE22_ARB=_C('GL_TEXTURE22_ARB',0x84D6)
GL_TEXTURE23_ARB=_C('GL_TEXTURE23_ARB',0x84D7)
GL_TEXTURE24_ARB=_C('GL_TEXTURE24_ARB',0x84D8)
GL_TEXTURE25_ARB=_C('GL_TEXTURE25_ARB',0x84D9)
GL_TEXTURE26_ARB=_C('GL_TEXTURE26_ARB',0x84DA)
GL_TEXTURE27_ARB=_C('GL_TEXTURE27_ARB',0x84DB)
GL_TEXTURE28_ARB=_C('GL_TEXTURE28_ARB',0x84DC)
GL_TEXTURE29_ARB=_C('GL_TEXTURE29_ARB',0x84DD)
GL_TEXTURE2_ARB=_C('GL_TEXTURE2_ARB',0x84C2)
GL_TEXTURE30_ARB=_C('GL_TEXTURE30_ARB',0x84DE)
GL_TEXTURE31_ARB=_C('GL_TEXTURE31_ARB',0x84DF)
GL_TEXTURE3_ARB=_C('GL_TEXTURE3_ARB',0x84C3)
GL_TEXTURE4_ARB=_C('GL_TEXTURE4_ARB',0x84C4)
GL_TEXTURE5_ARB=_C('GL_TEXTURE5_ARB',0x84C5)
GL_TEXTURE6_ARB=_C('GL_TEXTURE6_ARB',0x84C6)
GL_TEXTURE7_ARB=_C('GL_TEXTURE7_ARB',0x84C7)
GL_TEXTURE8_ARB=_C('GL_TEXTURE8_ARB',0x84C8)
GL_TEXTURE9_ARB=_C('GL_TEXTURE9_ARB',0x84C9)
@_f
@_p.types(None,_cs.GLenum)
def glActiveTextureARB(texture):pass
@_f
@_p.types(None,_cs.GLenum)
def glClientActiveTextureARB(texture):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble)
def glMultiTexCoord1dARB(target,s):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glMultiTexCoord1dvARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat)
def glMultiTexCoord1fARB(target,s):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glMultiTexCoord1fvARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint)
def glMultiTexCoord1iARB(target,s):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glMultiTexCoord1ivARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLshort)
def glMultiTexCoord1sARB(target,s):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLshortArray)
def glMultiTexCoord1svARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble,_cs.GLdouble)
def glMultiTexCoord2dARB(target,s,t):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glMultiTexCoord2dvARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat)
def glMultiTexCoord2fARB(target,s,t):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glMultiTexCoord2fvARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint)
def glMultiTexCoord2iARB(target,s,t):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glMultiTexCoord2ivARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLshort,_cs.GLshort)
def glMultiTexCoord2sARB(target,s,t):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLshortArray)
def glMultiTexCoord2svARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glMultiTexCoord3dARB(target,s,t,r):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glMultiTexCoord3dvARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glMultiTexCoord3fARB(target,s,t,r):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glMultiTexCoord3fvARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint)
def glMultiTexCoord3iARB(target,s,t,r):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glMultiTexCoord3ivARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glMultiTexCoord3sARB(target,s,t,r):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLshortArray)
def glMultiTexCoord3svARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble,_cs.GLdouble)
def glMultiTexCoord4dARB(target,s,t,r,q):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLdoubleArray)
def glMultiTexCoord4dvARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat,_cs.GLfloat)
def glMultiTexCoord4fARB(target,s,t,r,q):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLfloatArray)
def glMultiTexCoord4fvARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLint,_cs.GLint,_cs.GLint,_cs.GLint)
def glMultiTexCoord4iARB(target,s,t,r,q):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLintArray)
def glMultiTexCoord4ivARB(target,v):pass
@_f
@_p.types(None,_cs.GLenum,_cs.GLshort,_cs.GLshort,_cs.GLshort,_cs.GLshort)
def glMultiTexCoord4sARB(target,s,t,r,q):pass
@_f
@_p.types(None,_cs.GLenum,arrays.GLshortArray)
def glMultiTexCoord4svARB(target,v):pass
